Introduction
============

pydevDAG is a library for directed acyclic graphs of device configurations.
It constructs graphs that encode various relationships between devices,
caches them, displays the graphs both graphically and textually,
and compares graphs to detect changes in a device configuration.
